/*
 * Copyright (c) 2016 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <stdio.h>
#include <stdbool.h>
#include <zephyr/kernel.h>
#include <zephyr/drivers/gpio.h>
#include <hal/nrf_power.h>
#include <zephyr/init.h>
#include <nrfx_power.h>
#include <zephyr/logging/log.h>

#include "hw_init.h"
#include "TaskLED.h"
#include "TaskBEEP.h"
#include "TaskButton.h"
#include "TaskMain.h"
#include "SystemConfig.h"

LOG_MODULE_REGISTER(main, LOG_LEVEL_INF);

static int enable_dcdc_init(void)
{
    nrf_power_dcdcen_set(NRF_POWER, true);

    return 0;
}

// Zařadíme inicializační funkci do boot sekvence (před kernel startem)
SYS_INIT(enable_dcdc_init, PRE_KERNEL_1, 0);


void log_stack_usage(const char *task_name)
{
    size_t unused = 0;
    if (k_thread_stack_space_get(k_current_get(), &unused) != 0)
    {
        LOG_ERR("[%s] Failed to get stack usage", task_name);
        return;
    }

    if (unused <= STACK_WARN_THRESHOLD)
    {
        LOG_ERR("[%s] STACK LOW: %u B", task_name, unused);
    }
    else
    {
        LOG_INF("[%s] stack OK: %u B", task_name, unused);
    }
}


int main(void)
{
	int ret;
	bool led_state = true;

	if (hw_init() == false)
	{
		LOG_ERR("HW init failed");
		return -1;
	}

	LOG_INF("HW initialized");

	TaskMain_Start();

	while (1) {
	
		k_msleep(10000);
	}
	return 0;
}
